@@ -1,12 +1,12 @@
 package Debug::Client;
 
 use v5.10;
-use strict;
-use warnings;
+use strictures 1;
 
-local $| = 1; # Turn on $OUTPUT_AUTOFLUSH
+# Turn on $OUTPUT_AUTOFLUSH
+local $| = 1;
 
-our $VERSION = '0.21_08';
+our $VERSION = '0.21_10';
 
 use utf8;
 use IO::Socket::IP;
@@ -675,7 +675,7 @@ Debug::Client - debugger client side code for Padre, The Perl IDE.
 
 =head1 VERSION
 
-This document describes Debug::Client version 0.21_08
+This document describes Debug::Client version 0.21_10
 
 =head1 SYNOPSIS
 
@@ -1070,7 +1070,9 @@ Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt>
 
 Mark Gardner E<lt>mjgardner@cpan.orgE<gt>
 
-Wolfram Humann E<lt>whumann@cpan.orgE<gt> 
+Wolfram Humann E<lt>whumann@cpan.orgE<gt>
+
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
